##  Required Data
The AI governance and AI agent extensions to the meta model provide dedicated fact sheet subtypes and attributes for AI-related information. The table below lists the key changes introduced by these extensions. Collect these attributes from experts to enrich your data.
Meta Model Extensions: AI Governance and AI Agent Extension | Fact Sheets and Attributes | Detailed Information
---|---|---
AI governance |  New field on business capability fact sheets:
  * AI Potential

New fields on application fact sheets:
  * AI Usage
  * AI Risk
  * Type of Artificial Intelligence (AI)
  * Type of Artificial Intelligence (AI) Description
  * AI Potential

IT component fact sheets:
  * New subtype: AI model
  * New field: AI Radar Classification

| [AI Governance Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension?locale=en-US&state=PRODUCTION&version=CLOUD "Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.")
AI agent |  Application fact sheets:
  * New subtype: AI agent
  * New subtype (if not yet added): business application

Interface fact sheets:
  * New subtype: MCP server
  * New attributes on the API fact sheet subtype

| [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.")


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
